@@ -7,15 +7,17 @@ import numpy as np
 from scipy import sparse
 from sympy import Integer, log, Matrix
 from sympy.matrices import SparseMatrix
-from radioactivedecay import decaydata, icrp107
+from radioactivedecay import decaydata, icrp107_ame2020_nubase2020
 
 
-class Test(unittest.TestCase):
+class TestDecayDataFunctions(unittest.TestCase):
     """
-    Unit tests for decaydata.py functions, classes and methods.
+    Unit tests for the decaydata.py functions.
     """
 
-    def test__csr_matrix_equal(self):
+    # pylint: disable=protected-access
+
+    def test__csr_matrix_equal(self) -> None:
         """
         Test function to check equality of two SciPy Compressed Sparse Row (CSR) matrices.
         """
@@ -26,19 +28,26 @@ class Test(unittest.TestCase):
         self.assertEqual(decaydata._csr_matrix_equal(matrix_a, matrix_b), True)
         self.assertEqual(decaydata._csr_matrix_equal(matrix_a, matrix_c), False)
 
-    def test_decaymatrices_instantiation(self):
+
+class TestDecayMatrices(unittest.TestCase):
+    """
+    Unit tests for the decaydata.py DecayMatrices class.
+    """
+
+    def test_instantiation(self) -> None:
         """
         Test instantiation of DecayMatrices objects.
         """
 
-        # check with artificial SciPy data
+        atomic_masses = np.array([0.0] * 2)
         decay_consts = np.array([0.0] * 2)
         matrix_c = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
         matrix_c_inv = sparse.csr_matrix(([1.0], ([1], [1])), shape=(2, 2))
-        year_conv = 365.0
         decay_mats = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
         )
+        self.assertEqual(decay_mats.atomic_masses[0], 0.0)
+        self.assertEqual(decay_mats.atomic_masses[1], 0.0)
         self.assertEqual(decay_mats.decay_consts[0], 0.0)
         self.assertEqual(decay_mats.decay_consts[1], 0.0)
         self.assertEqual(decay_mats.ln2, np.log(2))
@@ -48,18 +57,92 @@ class Test(unittest.TestCase):
         self.assertEqual(decay_mats.matrix_e[1, 1], 0.0)
         self.assertEqual(decay_mats.vector_n0[0], 0.0)
         self.assertEqual(decay_mats.vector_n0[1], 0.0)
-        self.assertEqual(decay_mats.year_conv, year_conv)
 
-        # check with artificial SymPy data
+    def test_decaymatrices___eq__(self) -> None:
+        """
+        Test DecayMatrices equality.
+        """
+
+        atomic_masses = np.array([0.0] * 2)
+        decay_consts = np.array([0.0] * 2)
+        matrix_c = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
+        matrix_c_inv = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
+        decay_mats_a = decaydata.DecayMatrices(
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
+        )
+        atomic_masses = np.array([0.0] * 2)
+        decay_consts = np.array([0.0] * 2)
+        matrix_c = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
+        matrix_c_inv = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
+        decay_mats_b = decaydata.DecayMatrices(
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
+        )
+        self.assertEqual(decay_mats_a, decay_mats_b)
+
+        self.assertFalse(decay_mats_a == "random object")
+
+    def test_decaymatrices___ne__(self) -> None:
+        """
+        Test DecayMatrices inequal.
+        """
+
+        atomic_masses = np.array([0.0] * 2)
+        decay_consts = np.array([0.0] * 2)
+        matrix_c = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
+        matrix_c_inv = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
+        decay_mats_a = decaydata.DecayMatrices(
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
+        )
+        atomic_masses = np.array([0.0] * 2)
+        decay_consts = np.array([0.0] * 2)
+        matrix_c = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
+        matrix_c_inv = sparse.csr_matrix(([2.0], ([0], [0])), shape=(2, 2))
+        decay_mats_b = decaydata.DecayMatrices(
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
+        )
+        self.assertNotEqual(decay_mats_a, decay_mats_b)
+
+        self.assertTrue(decay_mats_a != "random object")
+
+    def test_decaymatrices___repr__(self) -> None:
+        """
+        Test DecayMatrices __repr__ strings.
+        """
+
+        atomic_masses = np.array([0.0] * 2)
+        decay_consts = np.array([0.0] * 2)
+        matrix_c = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
+        matrix_c_inv = sparse.csr_matrix(([1.0], ([1], [1])), shape=(2, 2))
+        decay_mats = decaydata.DecayMatrices(
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
+        )
+        self.assertEqual(
+            decay_mats.__repr__(),
+            "DecayMatrices: data stored in SciPy/NumPy objects for double precision calculations.",
+        )
+
+
+class TestDecayMatricesSymPy(unittest.TestCase):
+    """
+    Unit tests for the decaydata.py DecayMatricesSympy class.
+    """
+
+    def test_instantiation(self) -> None:
+        """
+        Test instantiation of DecayMatricesSympy objects.
+        """
+
+        atomic_masses = Matrix.zeros(2, 1)
         decay_consts = Matrix.zeros(2, 1)
         matrix_c = SparseMatrix.zeros(2, 2)
         matrix_c[0, 0] = Integer(2)
         matrix_c_inv = SparseMatrix.zeros(2, 2)
         matrix_c_inv[1, 1] = Integer(3)
-        year_conv = Integer(36525) / Integer(365)
-        decay_mats = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
+        decay_mats = decaydata.DecayMatricesSympy(
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
         )
+        self.assertEqual(decay_mats.atomic_masses[0], 0.0)
+        self.assertEqual(decay_mats.atomic_masses[1], 0.0)
         self.assertEqual(decay_mats.decay_consts[0], 0.0)
         self.assertEqual(decay_mats.decay_consts[1], 0.0)
         self.assertEqual(decay_mats.ln2, log(2))
@@ -69,125 +152,87 @@ class Test(unittest.TestCase):
         self.assertEqual(decay_mats.matrix_e[1, 1], Integer(0))
         self.assertEqual(decay_mats.vector_n0[0], 0.0)
         self.assertEqual(decay_mats.vector_n0[1], 0.0)
-        self.assertEqual(decay_mats.year_conv, Integer(36525) / Integer(365))
 
-    def test_decaymatrices___eq__(self):
+    def test___eq__(self) -> None:
         """
-        Test DecayMatrices instances equal.
+        Test DecayMatricesSympy equality.
         """
 
-        # check with artificial SciPy data
-        decay_consts = np.array([0.0] * 2)
-        matrix_c = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
-        matrix_c_inv = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
-        year_conv = 365.0
-        decay_mats_a = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
-        )
-        decay_consts = np.array([0.0] * 2)
-        matrix_c = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
-        matrix_c_inv = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
-        year_conv = 365.0
-        decay_mats_b = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
-        )
-        self.assertEqual(decay_mats_a, decay_mats_b)
-
-        # check with artificial SymPy data
+        atomic_masses = Matrix.zeros(2, 1)
         decay_consts = Matrix.zeros(2, 1)
         matrix_c = SparseMatrix.zeros(2, 2)
         matrix_c[0, 0] = Integer(2)
         matrix_c_inv = SparseMatrix.zeros(2, 2)
         matrix_c_inv[1, 1] = Integer(3)
-        year_conv = Integer(36525) / Integer(365)
-        decay_mats_a = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
+        decay_mats_a = decaydata.DecayMatricesSympy(
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
         )
+        atomic_masses = Matrix.zeros(2, 1)
         matrix_c = SparseMatrix.zeros(2, 2)
         matrix_c[0, 0] = Integer(2)
         matrix_c_inv = SparseMatrix.zeros(2, 2)
         matrix_c_inv[1, 1] = Integer(3)
-        year_conv = Integer(36525) / Integer(365)
-        decay_mats_b = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
+        decay_mats_b = decaydata.DecayMatricesSympy(
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
         )
         self.assertEqual(decay_mats_a, decay_mats_b)
 
-    def test_decaymatrices___ne__(self):
+        self.assertFalse(decay_mats_a == "random object")
+
+    def test___ne__(self) -> None:
         """
-        Test DecayMatrices instances not equal.
+        Test DecayMatricesSympy inequality.
         """
 
-        # check with artificial SciPy data
-        decay_consts = np.array([0.0] * 2)
-        matrix_c = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
-        matrix_c_inv = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
-        year_conv = 365.0
-        decay_mats_a = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
-        )
-        decay_consts = np.array([0.0] * 2)
-        matrix_c = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
-        matrix_c_inv = sparse.csr_matrix(([2.0], ([0], [0])), shape=(2, 2))
-        year_conv = 365.0
-        decay_mats_b = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
-        )
-        self.assertNotEqual(decay_mats_a, decay_mats_b)
-
-        # check with artificial SymPy data
+        atomic_masses = Matrix.zeros(2, 1)
         decay_consts = Matrix.zeros(2, 1)
         matrix_c = SparseMatrix.zeros(2, 2)
         matrix_c[0, 0] = Integer(2)
         matrix_c_inv = SparseMatrix.zeros(2, 2)
         matrix_c_inv[1, 1] = Integer(3)
-        year_conv = Integer(36525) / Integer(365)
-        decay_mats_a = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
+        decay_mats_a = decaydata.DecayMatricesSympy(
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
         )
+        atomic_masses = Matrix.zeros(2, 1)
         decay_consts = Matrix.zeros(2, 1)
         matrix_c = SparseMatrix.zeros(2, 2)
         matrix_c[0, 0] = Integer(2)
         matrix_c_inv = SparseMatrix.zeros(2, 2)
         matrix_c_inv[1, 1] = Integer(5)
-        year_conv = Integer(36525) / Integer(365)
-        decay_mats_b = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
+        decay_mats_b = decaydata.DecayMatricesSympy(
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
         )
         self.assertNotEqual(decay_mats_a, decay_mats_b)
 
-    def test_decaymatrices___repr__(self):
+        self.assertTrue(decay_mats_a != "random object")
+
+    def test___repr__(self) -> None:
         """
-        Test DecayMatrices representations.
+        Test DecayMatricesSympy __repr__ strings.
         """
 
-        decay_consts = np.array([0.0] * 2)
-        matrix_c = sparse.csr_matrix(([1.0], ([0], [0])), shape=(2, 2))
-        matrix_c_inv = sparse.csr_matrix(([1.0], ([1], [1])), shape=(2, 2))
-        year_conv = 365.0
-        decay_mats = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
-        )
-        self.assertEqual(
-            decay_mats.__repr__(),
-            "DecayMatrices: data stored in SciPy/NumPy objects for double precision calculations.",
-        )
-
+        atomic_masses = Matrix.zeros(2, 1)
         decay_consts = Matrix.zeros(2, 1)
         matrix_c = SparseMatrix.zeros(2, 2)
         matrix_c[0, 0] = Integer(2)
         matrix_c_inv = SparseMatrix.zeros(2, 2)
         matrix_c_inv[1, 1] = Integer(3)
-        year_conv = Integer(36525) / Integer(365)
-        decay_mats = decaydata.DecayMatrices(
-            decay_consts, matrix_c, matrix_c_inv, year_conv
+        decay_mats = decaydata.DecayMatricesSympy(
+            atomic_masses, decay_consts, matrix_c, matrix_c_inv
         )
         self.assertEqual(
             decay_mats.__repr__(),
-            "DecayMatrices: data stored in SymPy objects for arbitrary-precision calculations.",
+            "DecayMatricesSympy: data stored in SymPy objects for arbitrary-precision "
+            + "calculations.",
         )
 
-    def test_decaydata_instantiation(self):
+
+class TestDecayData(unittest.TestCase):
+    """
+    Unit tests for the decaydata.py DecayData class.
+    """
+
+    def test_instantiation(self) -> None:
         """
         Test instantiation of DecayData objects.
         """
@@ -195,26 +240,24 @@ class Test(unittest.TestCase):
         # pylint: disable=too-many-statements
 
         # check instantiation from sub-package
-        data = decaydata.DecayData("icrp107", load_sympy=False)
-        self.assertEqual(data.dataset, "icrp107")
+        data = decaydata.DecayData("icrp107_ame2020_nubase2020", load_sympy=False)
+        self.assertEqual(data.dataset_name, "icrp107_ame2020_nubase2020")
         self.assertEqual(data.hldata[0][0], 100.5)
         self.assertEqual(data.hldata[0][1], "d")
-        self.assertEqual(data.hldata[-1][0], 12.32)
-        self.assertEqual(data.hldata[-1][1], "y")
-        self.assertEqual(data.num_radionuclides, 1252)
-        self.assertEqual(data.radionuclides[0], "Fm-257")
-        self.assertEqual(data.radionuclides[-1], "H-3")
-        self.assertEqual(data.radionuclide_dict["Fm-257"], 0)
-        self.assertEqual(data.radionuclide_dict["H-3"], 1251)
+        self.assertEqual(data.hldata[-1][0], np.inf)
+        self.assertEqual(data.hldata[-1][1], "s")
+        self.assertEqual(data.nuclides[0], "Fm-257")
+        self.assertEqual(data.nuclides[-1], "He-3")
+        self.assertEqual(data.nuclide_dict["Fm-257"], 0)
+        self.assertEqual(data.nuclide_dict["He-3"], 1497)
         self.assertEqual(list(data.prog_bfs_modes[0].keys())[0], "Cf-253")
         self.assertEqual(list(data.prog_bfs_modes[0].values())[0][0], 0.9979)
         self.assertEqual(list(data.prog_bfs_modes[0].values())[0][1], "\u03b1")
         self.assertEqual(list(data.prog_bfs_modes[0].keys())[1], "SF")
         self.assertEqual(list(data.prog_bfs_modes[0].values())[1][0], 0.0021)
         self.assertEqual(list(data.prog_bfs_modes[0].values())[1][1], "SF")
-        self.assertEqual(list(data.prog_bfs_modes[-1].keys())[0], "He-3")
-        self.assertEqual(list(data.prog_bfs_modes[-1].values())[0][0], 1.0)
-        self.assertEqual(list(data.prog_bfs_modes[-1].values())[0][1], "\u03b2-")
+        self.assertEqual(list(data.prog_bfs_modes[-1].keys()), [])
+        self.assertEqual(list(data.prog_bfs_modes[-1].values()), [])
         self.assertEqual(
             data.scipy_data.decay_consts[0], np.log(2) / (100.5 * 24 * 60 * 60)
         )
@@ -223,30 +266,31 @@ class Test(unittest.TestCase):
         self.assertEqual(data.scipy_data.matrix_c_inv[0, 0], 1.0)
         self.assertEqual(data.scipy_data.matrix_e[0, 0], 0.0)
         self.assertEqual(data.scipy_data.vector_n0[0], 0.0)
-        self.assertEqual(data.scipy_data.year_conv, 365.2422)
         self.assertEqual(data.sympy_data, None)
 
         # check instantiation with supplied dataset path
-        data = decaydata.DecayData("icrp107_2", icrp107.__path__[0], load_sympy=False)
-        self.assertEqual(data.dataset, "icrp107_2")
+        data = decaydata.DecayData(
+            "icrp107_ame2020_nubase2020_2",
+            icrp107_ame2020_nubase2020.__path__[0],
+            load_sympy=False,
+        )
+        self.assertEqual(data.dataset_name, "icrp107_ame2020_nubase2020_2")
         self.assertEqual(data.hldata[0][0], 100.5)
         self.assertEqual(data.hldata[0][1], "d")
-        self.assertEqual(data.hldata[-1][0], 12.32)
-        self.assertEqual(data.hldata[-1][1], "y")
-        self.assertEqual(data.num_radionuclides, 1252)
-        self.assertEqual(data.radionuclides[0], "Fm-257")
-        self.assertEqual(data.radionuclides[-1], "H-3")
-        self.assertEqual(data.radionuclide_dict["Fm-257"], 0)
-        self.assertEqual(data.radionuclide_dict["H-3"], 1251)
+        self.assertEqual(data.hldata[-1][0], np.inf)
+        self.assertEqual(data.hldata[-1][1], "s")
+        self.assertEqual(data.nuclides[0], "Fm-257")
+        self.assertEqual(data.nuclides[-1], "He-3")
+        self.assertEqual(data.nuclide_dict["Fm-257"], 0)
+        self.assertEqual(data.nuclide_dict["He-3"], 1497)
         self.assertEqual(list(data.prog_bfs_modes[0].keys())[0], "Cf-253")
         self.assertEqual(list(data.prog_bfs_modes[0].values())[0][0], 0.9979)
         self.assertEqual(list(data.prog_bfs_modes[0].values())[0][1], "\u03b1")
         self.assertEqual(list(data.prog_bfs_modes[0].keys())[1], "SF")
         self.assertEqual(list(data.prog_bfs_modes[0].values())[1][0], 0.0021)
         self.assertEqual(list(data.prog_bfs_modes[0].values())[1][1], "SF")
-        self.assertEqual(list(data.prog_bfs_modes[-1].keys())[0], "He-3")
-        self.assertEqual(list(data.prog_bfs_modes[-1].values())[0][0], 1.0)
-        self.assertEqual(list(data.prog_bfs_modes[-1].values())[0][1], "\u03b2-")
+        self.assertEqual(list(data.prog_bfs_modes[-1].keys()), [])
+        self.assertEqual(list(data.prog_bfs_modes[-1].values()), [])
         self.assertEqual(
             data.scipy_data.decay_consts[0], np.log(2) / (100.5 * 24 * 60 * 60)
         )
@@ -255,30 +299,27 @@ class Test(unittest.TestCase):
         self.assertEqual(data.scipy_data.matrix_c_inv[0, 0], 1.0)
         self.assertEqual(data.scipy_data.matrix_e[0, 0], 0.0)
         self.assertEqual(data.scipy_data.vector_n0[0], 0.0)
-        self.assertEqual(data.scipy_data.year_conv, 365.2422)
         self.assertEqual(data.sympy_data, None)
 
         # check instantiation from sub-package with SymPy data
-        data = decaydata.DecayData("icrp107", load_sympy=True)
-        self.assertEqual(data.dataset, "icrp107")
+        data = decaydata.DecayData("icrp107_ame2020_nubase2020", load_sympy=True)
+        self.assertEqual(data.dataset_name, "icrp107_ame2020_nubase2020")
         self.assertEqual(data.hldata[0][0], 100.5)
         self.assertEqual(data.hldata[0][1], "d")
-        self.assertEqual(data.hldata[-1][0], 12.32)
-        self.assertEqual(data.hldata[-1][1], "y")
-        self.assertEqual(data.num_radionuclides, 1252)
-        self.assertEqual(data.radionuclides[0], "Fm-257")
-        self.assertEqual(data.radionuclides[-1], "H-3")
-        self.assertEqual(data.radionuclide_dict["Fm-257"], 0)
-        self.assertEqual(data.radionuclide_dict["H-3"], 1251)
+        self.assertEqual(data.hldata[-1][0], np.inf)
+        self.assertEqual(data.hldata[-1][1], "s")
+        self.assertEqual(data.nuclides[0], "Fm-257")
+        self.assertEqual(data.nuclides[-1], "He-3")
+        self.assertEqual(data.nuclide_dict["Fm-257"], 0)
+        self.assertEqual(data.nuclide_dict["He-3"], 1497)
         self.assertEqual(list(data.prog_bfs_modes[0].keys())[0], "Cf-253")
         self.assertEqual(list(data.prog_bfs_modes[0].values())[0][0], 0.9979)
         self.assertEqual(list(data.prog_bfs_modes[0].values())[0][1], "\u03b1")
         self.assertEqual(list(data.prog_bfs_modes[0].keys())[1], "SF")
         self.assertEqual(list(data.prog_bfs_modes[0].values())[1][0], 0.0021)
         self.assertEqual(list(data.prog_bfs_modes[0].values())[1][1], "SF")
-        self.assertEqual(list(data.prog_bfs_modes[-1].keys())[0], "He-3")
-        self.assertEqual(list(data.prog_bfs_modes[-1].values())[0][0], 1.0)
-        self.assertEqual(list(data.prog_bfs_modes[-1].values())[0][1], "\u03b2-")
+        self.assertEqual(list(data.prog_bfs_modes[-1].keys()), [])
+        self.assertEqual(list(data.prog_bfs_modes[-1].values()), [])
         self.assertEqual(
             data.scipy_data.decay_consts[0], np.log(2) / (100.5 * 24 * 60 * 60)
         )
@@ -287,7 +328,6 @@ class Test(unittest.TestCase):
         self.assertEqual(data.scipy_data.matrix_c_inv[0, 0], 1.0)
         self.assertEqual(data.scipy_data.matrix_e[0, 0], 0.0)
         self.assertEqual(data.scipy_data.vector_n0[0], 0.0)
-        self.assertEqual(data.scipy_data.year_conv, 365.2422)
         self.assertEqual(
             data.sympy_data.decay_consts[0],
             log(2) * Integer(10) / (Integer(1005) * Integer(24) * Integer(3600)),
@@ -297,29 +337,30 @@ class Test(unittest.TestCase):
         self.assertEqual(data.sympy_data.matrix_c_inv[0, 0], Integer(1))
         self.assertEqual(data.sympy_data.matrix_e[0, 0], Integer(0))
         self.assertEqual(data.sympy_data.vector_n0[0], Integer(0))
-        self.assertEqual(data.sympy_data.year_conv, Integer(3652422) / Integer(10000))
 
         # check instantiation with supplied dataset path with SymPy data
-        data = decaydata.DecayData("icrp107_2", icrp107.__path__[0], load_sympy=True)
-        self.assertEqual(data.dataset, "icrp107_2")
+        data = decaydata.DecayData(
+            "icrp107_ame2020_nubase2020_2",
+            icrp107_ame2020_nubase2020.__path__[0],
+            load_sympy=True,
+        )
+        self.assertEqual(data.dataset_name, "icrp107_ame2020_nubase2020_2")
         self.assertEqual(data.hldata[0][0], 100.5)
         self.assertEqual(data.hldata[0][1], "d")
-        self.assertEqual(data.hldata[-1][0], 12.32)
-        self.assertEqual(data.hldata[-1][1], "y")
-        self.assertEqual(data.num_radionuclides, 1252)
-        self.assertEqual(data.radionuclides[0], "Fm-257")
-        self.assertEqual(data.radionuclides[-1], "H-3")
-        self.assertEqual(data.radionuclide_dict["Fm-257"], 0)
-        self.assertEqual(data.radionuclide_dict["H-3"], 1251)
+        self.assertEqual(data.hldata[-1][0], np.inf)
+        self.assertEqual(data.hldata[-1][1], "s")
+        self.assertEqual(data.nuclides[0], "Fm-257")
+        self.assertEqual(data.nuclides[-1], "He-3")
+        self.assertEqual(data.nuclide_dict["Fm-257"], 0)
+        self.assertEqual(data.nuclide_dict["He-3"], 1497)
         self.assertEqual(list(data.prog_bfs_modes[0].keys())[0], "Cf-253")
         self.assertEqual(list(data.prog_bfs_modes[0].values())[0][0], 0.9979)
         self.assertEqual(list(data.prog_bfs_modes[0].values())[0][1], "\u03b1")
         self.assertEqual(list(data.prog_bfs_modes[0].keys())[1], "SF")
         self.assertEqual(list(data.prog_bfs_modes[0].values())[1][0], 0.0021)
         self.assertEqual(list(data.prog_bfs_modes[0].values())[1][1], "SF")
-        self.assertEqual(list(data.prog_bfs_modes[-1].keys())[0], "He-3")
-        self.assertEqual(list(data.prog_bfs_modes[-1].values())[0][0], 1.0)
-        self.assertEqual(list(data.prog_bfs_modes[-1].values())[0][1], "\u03b2-")
+        self.assertEqual(list(data.prog_bfs_modes[-1].keys()), [])
+        self.assertEqual(list(data.prog_bfs_modes[-1].values()), [])
         self.assertEqual(
             data.scipy_data.decay_consts[0], np.log(2) / (100.5 * 24 * 60 * 60)
         )
@@ -328,7 +369,6 @@ class Test(unittest.TestCase):
         self.assertEqual(data.scipy_data.matrix_c_inv[0, 0], 1.0)
         self.assertEqual(data.scipy_data.matrix_e[0, 0], 0.0)
         self.assertEqual(data.scipy_data.vector_n0[0], 0.0)
-        self.assertEqual(data.scipy_data.year_conv, 365.2422)
         self.assertEqual(
             data.sympy_data.decay_consts[0],
             log(2) * Integer(10) / (Integer(1005) * Integer(24) * Integer(3600)),
@@ -338,14 +378,13 @@ class Test(unittest.TestCase):
         self.assertEqual(data.sympy_data.matrix_c_inv[0, 0], Integer(1))
         self.assertEqual(data.sympy_data.matrix_e[0, 0], Integer(0))
         self.assertEqual(data.sympy_data.vector_n0[0], Integer(0))
-        self.assertEqual(data.sympy_data.year_conv, Integer(3652422) / Integer(10000))
 
-    def test_decaydata_half_life(self):
+    def test_half_life(self) -> None:
         """
         Test DecayData half_life() method.
         """
 
-        data = decaydata.DecayData("icrp107")
+        data = decaydata.DecayData("icrp107_ame2020_nubase2020")
         self.assertEqual(data.half_life("H-3"), 388781329.30560005)
         self.assertEqual(data.half_life("H-3", "y"), 12.32)
         self.assertEqual(data.half_life("Fm-257", "h"), 2412.0)
@@ -357,56 +396,62 @@ class Test(unittest.TestCase):
         self.assertEqual(data.half_life("Rn-215", "readable"), "2.30 μs")
         self.assertEqual(data.half_life("U-238", "readable"), "4.468 By")
 
-    def test_decaydata_branching_fraction(self):
+    def test_branching_fraction(self) -> None:
         """
         Test DecayData branching_fraction() method.
         """
 
-        data = decaydata.DecayData("icrp107")
+        data = decaydata.DecayData("icrp107_ame2020_nubase2020")
         self.assertEqual(data.branching_fraction("K-40", "Ca-40"), 0.8914)
         self.assertEqual(data.branching_fraction("K-40", "H-3"), 0.0)
 
-    def test_decaydata_decay_mode(self):
+    def test_decay_mode(self) -> None:
         """
         Test DecayData decay_mode() method.
         """
 
-        data = decaydata.DecayData("icrp107")
+        data = decaydata.DecayData("icrp107_ame2020_nubase2020")
         self.assertEqual(data.decay_mode("K-40", "Ca-40"), "\u03b2-")
         self.assertEqual(data.decay_mode("K-40", "H-3"), "")
 
-    def test_decaydata___eq__(self):
+    def test_decaydata___eq__(self) -> None:
         """
         Test DecayData equality.
         """
 
-        data1 = decaydata.DecayData("icrp107")
-        data2 = decaydata.DecayData("icrp107")
+        data1 = decaydata.DecayData("icrp107_ame2020_nubase2020")
+        data2 = decaydata.DecayData("icrp107_ame2020_nubase2020")
         self.assertEqual(data1, data2)
 
-    def test_decaydata___ne__(self):
+        self.assertFalse(data1 == "random object")
+
+    def test_decaydata___ne__(self) -> None:
         """
-        Test DecayData not equality.
+        Test DecayData inequality.
         """
 
-        data1 = decaydata.DecayData("icrp107")
-        data2 = decaydata.DecayData("icrp107")
-        data2.dataset = "icrp07"
+        data1 = decaydata.DecayData("icrp107_ame2020_nubase2020")
+        data2 = decaydata.DecayData("icrp107_ame2020_nubase2020")
+        data2.dataset_name = "icrp07"
         self.assertNotEqual(data1, data2)
 
-    def test_decaydata___repr__(self):
+        self.assertTrue(data1 != "random object")
+
+    def test_decaydata___repr__(self) -> None:
         """
-        Test DecayData representations.
+        Test DecayData __repr__ strings.
         """
 
-        data = decaydata.DecayData("icrp107")
+        data = decaydata.DecayData("icrp107_ame2020_nubase2020")
         self.assertEqual(
-            data.__repr__(), "Decay dataset: icrp107, contains SymPy data: False"
+            data.__repr__(),
+            "Decay dataset: icrp107_ame2020_nubase2020, contains SymPy data: False",
         )
 
-        data = decaydata.DecayData("icrp107", load_sympy=True)
+        data = decaydata.DecayData("icrp107_ame2020_nubase2020", load_sympy=True)
         self.assertEqual(
-            data.__repr__(), "Decay dataset: icrp107, contains SymPy data: True"
+            data.__repr__(),
+            "Decay dataset: icrp107_ame2020_nubase2020, contains SymPy data: True",
         )
 
 
